:PyPI: https://pypi.python.org/pypi/pyramid_swagger
:Documentation: http://pyramid-swagger.readthedocs.org/en/latest/
:Source: https://github.com/striglia/pyramid_swagger
:License: Copyright © 2014 Scott Triglia under the `BSD 3-clause <http://opensource.org/licenses/BSD-3-Clause>`_
:Build status:
    .. image:: https://travis-ci.org/striglia/pyramid_swagger.png?branch=master
        :target: https://travis-ci.org/striglia/pyramid_swagger?branch=master
        :alt: Travis CI
:Current coverage on master:
    .. image:: https://coveralls.io/repos/striglia/pyramid_swagger/badge.png
        :target: https://coveralls.io/r/striglia/pyramid_swagger
:Persistent chat for questions: 
    .. image:: https://badges.gitter.im/Join%20Chat.svg
        :alt: Join the chat at https://gitter.im/striglia/pyramid_swagger
        :target: https://gitter.im/striglia/pyramid_swagger?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


pyramid_swagger
===============

This project offers convenient tools for using Swagger to define and validate
your interfaces in a Pyramid webapp.

Full documentation is available at http://pyramid-swagger.readthedocs.org/.
